@@ -1,11 +1,11 @@
 import requests
+from rowantree.contracts import ActionQueue
 
-from ..contracts.requests.action_queue_process import ActionQueueProcessRequest
 from .abstract_command import AbstractCommand
 
 
 class ActionQueueProcessCommand(AbstractCommand):
-    def execute(self, request: ActionQueueProcessRequest) -> None:
+    def execute(self, request: ActionQueue) -> None:
         requests.post(
             url=f"{self.config.endpoint}/v1/world/queue",
             data=request.json(by_alias=True),
